==> swagger-api__apidom-json-pointer-0.76.2.jar: META-INF/resources/webjars/swagger-api__apidom-json-pointer/0.76.2/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [0.76.2](https://github.com/swagger-api/apidom/compare/v0.76.1...v0.76.2) (2023-09-08)

### Bug Fixes

- **build:** apply polyfills with transform runtime babel plugin ([#3132](https://github.com/swagger-api/apidom/issues/3132)) ([4b4754d](https://github.com/swagger-api/apidom/commit/4b4754da33a4a25d47f926c8a14b59cfdfa6b50c))

## [0.76.1](https://github.com/swagger-api/apidom/compare/v0.76.0...v0.76.1) (2023-09-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.76.0](https://github.com/swagger-api/apidom/compare/v0.75.0...v0.76.0) (2023-09-01)

### Features

- **json-path:** use error hierarchy and metadata when throwing errors ([#3107](https://github.com/swagger-api/apidom/issues/3107)) ([d55a846](https://github.com/swagger-api/apidom/commit/d55a8466de9814f19aedbacb48c55761f2f3fe38)), closes [#3039](https://github.com/swagger-api/apidom/issues/3039)
- **json-pointer:** use error hierarchy and metadata when throwing errors ([#3106](https://github.com/swagger-api/apidom/issues/3106)) ([a17f250](https://github.com/swagger-api/apidom/commit/a17f25052db0d83f1ac3fcea94f2e58b50105df8)), closes [#3039](https://github.com/swagger-api/apidom/issues/3039)

# [0.75.0](https://github.com/swagger-api/apidom/compare/v0.74.1...v0.75.0) (2023-08-22)

### Features

- add support for Relative JSON Pointer ([#3031](https://github.com/swagger-api/apidom/issues/3031)) ([f537584](https://github.com/swagger-api/apidom/commit/f537584adc4559f682e2a5995b2419b043ad71c5)), closes [#3030](https://github.com/swagger-api/apidom/issues/3030)

## [0.74.1](https://github.com/swagger-api/apidom/compare/v0.74.0...v0.74.1) (2023-07-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.74.0](https://github.com/swagger-api/apidom/compare/v0.73.0...v0.74.0) (2023-07-24)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.73.0](https://github.com/swagger-api/apidom/compare/v0.72.0...v0.73.0) (2023-07-18)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.72.0](https://github.com/swagger-api/apidom/compare/v0.71.1...v0.72.0) (2023-07-17)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.71.0](https://github.com/swagger-api/apidom/compare/v0.70.4...v0.71.0) (2023-07-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.70.1](https://github.com/swagger-api/apidom/compare/v0.70.0...v0.70.1) (2023-06-15)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.70.0](https://github.com/swagger-api/apidom/compare/v0.69.3...v0.70.0) (2023-05-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.3](https://github.com/swagger-api/apidom/compare/v0.69.2...v0.69.3) (2023-04-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.2](https://github.com/swagger-api/apidom/compare/v0.69.1...v0.69.2) (2023-04-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.1](https://github.com/swagger-api/apidom/compare/v0.69.0...v0.69.1) (2023-03-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.69.0](https://github.com/swagger-api/apidom/compare/v0.68.1...v0.69.0) (2023-02-28)

### Features

- add support for publishing to npmjs.com ([#2597](https://github.com/swagger-api/apidom/issues/2597)) ([5ac3cd9](https://github.com/swagger-api/apidom/commit/5ac3cd9a83bbe3b4ce2fac732633fb179cd9747f)), closes [#2290](https://github.com/swagger-api/apidom/issues/2290)

## [0.68.1](https://github.com/swagger-api/apidom/compare/v0.68.0...v0.68.1) (2023-02-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.68.0](https://github.com/swagger-api/apidom/compare/v0.67.1...v0.68.0) (2023-02-16)

### Features

- **json-pointer:** add sideEffects field to package.json ([85d32e9](https://github.com/swagger-api/apidom/commit/85d32e9d01af4ba9d6598d3f9c4649390b4348f7)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

## [0.67.1](https://github.com/swagger-api/apidom/compare/v0.67.0...v0.67.1) (2023-02-15)

### Bug Fixes

- **deps:** relax @babel/runtime-corejs3 version ([#2563](https://github.com/swagger-api/apidom/issues/2563)) ([3523a14](https://github.com/swagger-api/apidom/commit/3523a145a8390bb85139d9a8c3919b0c4ef75962)), closes [#2562](https://github.com/swagger-api/apidom/issues/2562)

# [0.67.0](https://github.com/swagger-api/apidom/compare/v0.66.0...v0.67.0) (2023-02-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.66.0](https://github.com/swagger-api/apidom/compare/v0.65.0...v0.66.0) (2023-01-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.65.0](https://github.com/swagger-api/apidom/compare/v0.64.0...v0.65.0) (2023-01-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.64.0](https://github.com/swagger-api/apidom/compare/v0.63.1...v0.64.0) (2023-01-16)

### Bug Fixes

- **json-pointer:** fix JSON Pointer evaluation for % character ([#2461](https://github.com/swagger-api/apidom/issues/2461)) ([cc7167d](https://github.com/swagger-api/apidom/commit/cc7167d66844fde0b279d0dc063712acb622b615)), closes [/www.rfc-editor.org/rfc/rfc6901#section-5](https://github.com//www.rfc-editor.org/rfc/rfc6901/issues/section-5)

# [0.63.0](https://github.com/swagger-api/apidom/compare/v0.62.1...v0.63.0) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.62.1](https://github.com/swagger-api/apidom/compare/v0.62.0...v0.62.1) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.62.0](https://github.com/swagger-api/apidom/compare/v0.61.0...v0.62.0) (2023-01-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.61.0](https://github.com/swagger-api/apidom/compare/v0.60.0...v0.61.0) (2022-12-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.60.0](https://github.com/swagger-api/apidom/compare/v0.59.0...v0.60.0) (2022-12-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.59.0](https://github.com/swagger-api/apidom/compare/v0.58.0...v0.59.0) (2022-12-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.58.0](https://github.com/swagger-api/apidom/compare/v0.57.0...v0.58.0) (2022-12-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.57.0](https://github.com/swagger-api/apidom/compare/v0.56.3...v0.57.0) (2022-12-08)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.2](https://github.com/swagger-api/apidom/compare/v0.56.1...v0.56.2) (2022-11-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.1](https://github.com/swagger-api/apidom/compare/v0.56.0...v0.56.1) (2022-11-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.56.0](https://github.com/swagger-api/apidom/compare/v0.55.1...v0.56.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.55.0](https://github.com/swagger-api/apidom/compare/v0.54.0...v0.55.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.54.0](https://github.com/swagger-api/apidom/compare/v0.53.0...v0.54.0) (2022-10-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.53.0](https://github.com/swagger-api/apidom/compare/v0.52.0...v0.53.0) (2022-10-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.52.0](https://github.com/swagger-api/apidom/compare/v0.51.1...v0.52.0) (2022-10-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.51.1](https://github.com/swagger-api/apidom/compare/v0.51.0...v0.51.1) (2022-10-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.51.0](https://github.com/swagger-api/apidom/compare/v0.50.0...v0.51.0) (2022-10-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.50.0](https://github.com/swagger-api/apidom/compare/v0.49.0...v0.50.0) (2022-10-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.49.0](https://github.com/swagger-api/apidom/compare/v0.48.0...v0.49.0) (2022-10-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.48.0](https://github.com/swagger-api/apidom/compare/v0.47.0...v0.48.0) (2022-10-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.47.0](https://github.com/swagger-api/apidom/compare/v0.46.0...v0.47.0) (2022-09-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.46.0](https://github.com/swagger-api/apidom/compare/v0.45.0...v0.46.0) (2022-09-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.45.0](https://github.com/swagger-api/apidom/compare/v0.44.0...v0.45.0) (2022-09-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.44.0](https://github.com/swagger-api/apidom/compare/v0.43.0...v0.44.0) (2022-09-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.43.0](https://github.com/swagger-api/apidom/compare/v0.42.0...v0.43.0) (2022-08-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.42.0](https://github.com/swagger-api/apidom/compare/v0.41.1...v0.42.0) (2022-08-30)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.41.0](https://github.com/swagger-api/apidom/compare/v0.40.3...v0.41.0) (2022-08-19)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.40.0](https://github.com/swagger-api/apidom/compare/v0.39.0...v0.40.0) (2022-08-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.39.0](https://github.com/swagger-api/apidom/compare/v0.38.0...v0.39.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.38.0](https://github.com/swagger-api/apidom/compare/v0.37.0...v0.38.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.37.0](https://github.com/swagger-api/apidom/compare/v0.36.0...v0.37.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.36.0](https://github.com/swagger-api/apidom/compare/v0.35.1...v0.36.0) (2022-07-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.35.0](https://github.com/swagger-api/apidom/compare/v0.34.0...v0.35.0) (2022-07-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.34.0](https://github.com/swagger-api/apidom/compare/v0.33.0...v0.34.0) (2022-07-01)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.33.0](https://github.com/swagger-api/apidom/compare/v0.32.0...v0.33.0) (2022-06-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.32.0](https://github.com/swagger-api/apidom/compare/v0.31.2...v0.32.0) (2022-06-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.31.2](https://github.com/swagger-api/apidom/compare/v0.31.1...v0.31.2) (2022-06-24)

### Bug Fixes

- **build:** make using minim an implementation detail ([a45009f](https://github.com/swagger-api/apidom/commit/a45009fef5855f3b2fba699c9e4faf560c613443)), closes [#1632](https://github.com/swagger-api/apidom/issues/1632)

## [0.31.1](https://github.com/swagger-api/apidom/compare/v0.31.0...v0.31.1) (2022-06-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.31.0](https://github.com/swagger-api/apidom/compare/v0.30.1...v0.31.0) (2022-06-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.30.0](https://github.com/swagger-api/apidom/compare/v0.29.1...v0.30.0) (2022-06-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.29.1](https://github.com/swagger-api/apidom/compare/v0.29.0...v0.29.1) (2022-06-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.29.0](https://github.com/swagger-api/apidom/compare/v0.28.0...v0.29.0) (2022-05-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.28.0](https://github.com/swagger-api/apidom/compare/v0.27.0...v0.28.0) (2022-05-22)

### Features

- **json-pointer:** add support for JSON Pointer ([#1492](https://github.com/swagger-api/apidom/issues/1492)) ([2b75806](https://github.com/swagger-api/apidom/commit/2b75806964edce80110d2a190a91d7b8ab4c0ff1)), closes [#1491](https://github.com/swagger-api/apidom/issues/1491)

==> swagger-api__apidom-json-pointer-0.83.0.jar: META-INF/resources/webjars/swagger-api__apidom-json-pointer/0.83.0/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.83.0](https://github.com/swagger-api/apidom/compare/v0.82.2...v0.83.0) (2023-11-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.82.2](https://github.com/swagger-api/apidom/compare/v0.82.1...v0.82.2) (2023-11-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.82.1](https://github.com/swagger-api/apidom/compare/v0.82.0...v0.82.1) (2023-11-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.82.0](https://github.com/swagger-api/apidom/compare/v0.81.0...v0.82.0) (2023-11-01)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.81.0](https://github.com/swagger-api/apidom/compare/v0.80.0...v0.81.0) (2023-10-30)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.80.0](https://github.com/swagger-api/apidom/compare/v0.79.0...v0.80.0) (2023-10-26)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.79.0](https://github.com/swagger-api/apidom/compare/v0.78.0...v0.79.0) (2023-10-24)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.78.0](https://github.com/swagger-api/apidom/compare/v0.77.0...v0.78.0) (2023-10-17)

### Bug Fixes

- **types:** fix regression in @types/ramda@0.29.6 ([#3281](https://github.com/swagger-api/apidom/issues/3281)) ([c6c279f](https://github.com/swagger-api/apidom/commit/c6c279f526e07b16221d8c00dd0041eeb93e1290)), closes [#3279](https://github.com/swagger-api/apidom/issues/3279)

# [0.77.0](https://github.com/swagger-api/apidom/compare/v0.76.2...v0.77.0) (2023-10-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.76.2](https://github.com/swagger-api/apidom/compare/v0.76.1...v0.76.2) (2023-09-08)

### Bug Fixes

- **build:** apply polyfills with transform runtime babel plugin ([#3132](https://github.com/swagger-api/apidom/issues/3132)) ([4b4754d](https://github.com/swagger-api/apidom/commit/4b4754da33a4a25d47f926c8a14b59cfdfa6b50c))

## [0.76.1](https://github.com/swagger-api/apidom/compare/v0.76.0...v0.76.1) (2023-09-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.76.0](https://github.com/swagger-api/apidom/compare/v0.75.0...v0.76.0) (2023-09-01)

### Features

- **json-path:** use error hierarchy and metadata when throwing errors ([#3107](https://github.com/swagger-api/apidom/issues/3107)) ([d55a846](https://github.com/swagger-api/apidom/commit/d55a8466de9814f19aedbacb48c55761f2f3fe38)), closes [#3039](https://github.com/swagger-api/apidom/issues/3039)
- **json-pointer:** use error hierarchy and metadata when throwing errors ([#3106](https://github.com/swagger-api/apidom/issues/3106)) ([a17f250](https://github.com/swagger-api/apidom/commit/a17f25052db0d83f1ac3fcea94f2e58b50105df8)), closes [#3039](https://github.com/swagger-api/apidom/issues/3039)

# [0.75.0](https://github.com/swagger-api/apidom/compare/v0.74.1...v0.75.0) (2023-08-22)

### Features

- add support for Relative JSON Pointer ([#3031](https://github.com/swagger-api/apidom/issues/3031)) ([f537584](https://github.com/swagger-api/apidom/commit/f537584adc4559f682e2a5995b2419b043ad71c5)), closes [#3030](https://github.com/swagger-api/apidom/issues/3030)

## [0.74.1](https://github.com/swagger-api/apidom/compare/v0.74.0...v0.74.1) (2023-07-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.74.0](https://github.com/swagger-api/apidom/compare/v0.73.0...v0.74.0) (2023-07-24)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.73.0](https://github.com/swagger-api/apidom/compare/v0.72.0...v0.73.0) (2023-07-18)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.72.0](https://github.com/swagger-api/apidom/compare/v0.71.1...v0.72.0) (2023-07-17)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.71.0](https://github.com/swagger-api/apidom/compare/v0.70.4...v0.71.0) (2023-07-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.70.1](https://github.com/swagger-api/apidom/compare/v0.70.0...v0.70.1) (2023-06-15)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.70.0](https://github.com/swagger-api/apidom/compare/v0.69.3...v0.70.0) (2023-05-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.3](https://github.com/swagger-api/apidom/compare/v0.69.2...v0.69.3) (2023-04-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.2](https://github.com/swagger-api/apidom/compare/v0.69.1...v0.69.2) (2023-04-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.1](https://github.com/swagger-api/apidom/compare/v0.69.0...v0.69.1) (2023-03-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.69.0](https://github.com/swagger-api/apidom/compare/v0.68.1...v0.69.0) (2023-02-28)

### Features

- add support for publishing to npmjs.com ([#2597](https://github.com/swagger-api/apidom/issues/2597)) ([5ac3cd9](https://github.com/swagger-api/apidom/commit/5ac3cd9a83bbe3b4ce2fac732633fb179cd9747f)), closes [#2290](https://github.com/swagger-api/apidom/issues/2290)

## [0.68.1](https://github.com/swagger-api/apidom/compare/v0.68.0...v0.68.1) (2023-02-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.68.0](https://github.com/swagger-api/apidom/compare/v0.67.1...v0.68.0) (2023-02-16)

### Features

- **json-pointer:** add sideEffects field to package.json ([85d32e9](https://github.com/swagger-api/apidom/commit/85d32e9d01af4ba9d6598d3f9c4649390b4348f7)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

## [0.67.1](https://github.com/swagger-api/apidom/compare/v0.67.0...v0.67.1) (2023-02-15)

### Bug Fixes

- **deps:** relax @babel/runtime-corejs3 version ([#2563](https://github.com/swagger-api/apidom/issues/2563)) ([3523a14](https://github.com/swagger-api/apidom/commit/3523a145a8390bb85139d9a8c3919b0c4ef75962)), closes [#2562](https://github.com/swagger-api/apidom/issues/2562)

# [0.67.0](https://github.com/swagger-api/apidom/compare/v0.66.0...v0.67.0) (2023-02-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.66.0](https://github.com/swagger-api/apidom/compare/v0.65.0...v0.66.0) (2023-01-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.65.0](https://github.com/swagger-api/apidom/compare/v0.64.0...v0.65.0) (2023-01-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.64.0](https://github.com/swagger-api/apidom/compare/v0.63.1...v0.64.0) (2023-01-16)

### Bug Fixes

- **json-pointer:** fix JSON Pointer evaluation for % character ([#2461](https://github.com/swagger-api/apidom/issues/2461)) ([cc7167d](https://github.com/swagger-api/apidom/commit/cc7167d66844fde0b279d0dc063712acb622b615)), closes [/www.rfc-editor.org/rfc/rfc6901#section-5](https://github.com//www.rfc-editor.org/rfc/rfc6901/issues/section-5)

# [0.63.0](https://github.com/swagger-api/apidom/compare/v0.62.1...v0.63.0) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.62.1](https://github.com/swagger-api/apidom/compare/v0.62.0...v0.62.1) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.62.0](https://github.com/swagger-api/apidom/compare/v0.61.0...v0.62.0) (2023-01-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.61.0](https://github.com/swagger-api/apidom/compare/v0.60.0...v0.61.0) (2022-12-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.60.0](https://github.com/swagger-api/apidom/compare/v0.59.0...v0.60.0) (2022-12-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.59.0](https://github.com/swagger-api/apidom/compare/v0.58.0...v0.59.0) (2022-12-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.58.0](https://github.com/swagger-api/apidom/compare/v0.57.0...v0.58.0) (2022-12-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.57.0](https://github.com/swagger-api/apidom/compare/v0.56.3...v0.57.0) (2022-12-08)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.2](https://github.com/swagger-api/apidom/compare/v0.56.1...v0.56.2) (2022-11-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.1](https://github.com/swagger-api/apidom/compare/v0.56.0...v0.56.1) (2022-11-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.56.0](https://github.com/swagger-api/apidom/compare/v0.55.1...v0.56.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.55.0](https://github.com/swagger-api/apidom/compare/v0.54.0...v0.55.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.54.0](https://github.com/swagger-api/apidom/compare/v0.53.0...v0.54.0) (2022-10-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.53.0](https://github.com/swagger-api/apidom/compare/v0.52.0...v0.53.0) (2022-10-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.52.0](https://github.com/swagger-api/apidom/compare/v0.51.1...v0.52.0) (2022-10-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.51.1](https://github.com/swagger-api/apidom/compare/v0.51.0...v0.51.1) (2022-10-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.51.0](https://github.com/swagger-api/apidom/compare/v0.50.0...v0.51.0) (2022-10-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.50.0](https://github.com/swagger-api/apidom/compare/v0.49.0...v0.50.0) (2022-10-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.49.0](https://github.com/swagger-api/apidom/compare/v0.48.0...v0.49.0) (2022-10-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.48.0](https://github.com/swagger-api/apidom/compare/v0.47.0...v0.48.0) (2022-10-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.47.0](https://github.com/swagger-api/apidom/compare/v0.46.0...v0.47.0) (2022-09-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.46.0](https://github.com/swagger-api/apidom/compare/v0.45.0...v0.46.0) (2022-09-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.45.0](https://github.com/swagger-api/apidom/compare/v0.44.0...v0.45.0) (2022-09-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.44.0](https://github.com/swagger-api/apidom/compare/v0.43.0...v0.44.0) (2022-09-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.43.0](https://github.com/swagger-api/apidom/compare/v0.42.0...v0.43.0) (2022-08-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.42.0](https://github.com/swagger-api/apidom/compare/v0.41.1...v0.42.0) (2022-08-30)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.41.0](https://github.com/swagger-api/apidom/compare/v0.40.3...v0.41.0) (2022-08-19)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.40.0](https://github.com/swagger-api/apidom/compare/v0.39.0...v0.40.0) (2022-08-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.39.0](https://github.com/swagger-api/apidom/compare/v0.38.0...v0.39.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.38.0](https://github.com/swagger-api/apidom/compare/v0.37.0...v0.38.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.37.0](https://github.com/swagger-api/apidom/compare/v0.36.0...v0.37.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.36.0](https://github.com/swagger-api/apidom/compare/v0.35.1...v0.36.0) (2022-07-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.35.0](https://github.com/swagger-api/apidom/compare/v0.34.0...v0.35.0) (2022-07-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.34.0](https://github.com/swagger-api/apidom/compare/v0.33.0...v0.34.0) (2022-07-01)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.33.0](https://github.com/swagger-api/apidom/compare/v0.32.0...v0.33.0) (2022-06-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.32.0](https://github.com/swagger-api/apidom/compare/v0.31.2...v0.32.0) (2022-06-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.31.2](https://github.com/swagger-api/apidom/compare/v0.31.1...v0.31.2) (2022-06-24)

### Bug Fixes

- **build:** make using minim an implementation detail ([a45009f](https://github.com/swagger-api/apidom/commit/a45009fef5855f3b2fba699c9e4faf560c613443)), closes [#1632](https://github.com/swagger-api/apidom/issues/1632)

## [0.31.1](https://github.com/swagger-api/apidom/compare/v0.31.0...v0.31.1) (2022-06-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.31.0](https://github.com/swagger-api/apidom/compare/v0.30.1...v0.31.0) (2022-06-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.30.0](https://github.com/swagger-api/apidom/compare/v0.29.1...v0.30.0) (2022-06-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.29.1](https://github.com/swagger-api/apidom/compare/v0.29.0...v0.29.1) (2022-06-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.29.0](https://github.com/swagger-api/apidom/compare/v0.28.0...v0.29.0) (2022-05-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.28.0](https://github.com/swagger-api/apidom/compare/v0.27.0...v0.28.0) (2022-05-22)

### Features

- **json-pointer:** add support for JSON Pointer ([#1492](https://github.com/swagger-api/apidom/issues/1492)) ([2b75806](https://github.com/swagger-api/apidom/commit/2b75806964edce80110d2a190a91d7b8ab4c0ff1)), closes [#1491](https://github.com/swagger-api/apidom/issues/1491)
